@@ -8,6 +8,10 @@ class Ipam(object):
 
         self.netbox_con = netbox_con
 
+    def get_services(self, **kwargs):
+        """Return all services"""
+        return self.netbox_con.get('/ipam/services/', **kwargs)
+
     def get_ip_addresses(self, **kwargs):
         """Return all ip addresses"""
         return self.netbox_con.get('/ipam/ip-addresses/', **kwargs)
@@ -21,7 +25,7 @@ class Ipam(object):
         return self.netbox_con.get('/ipam/ip-addresses', device=device_name)
 
     def get_ip_by_virtual_machine(self, vm_name):
-        """Get IPs which are associated to a device
+        """Get IPs which are associated to a virtual-machine
 
         :param vm_name: Name of the virtual machine
         :return: ip address information
@@ -316,7 +320,7 @@ class Ipam(object):
         return self.netbox_con.patch('/ipam/vlans/', vlan_id, **kwargs)
 
     def get_vlan_groups(self, **kwargs):
-        """Return all vlans"""
+        """Return all vlan groups"""
         return self.netbox_con.get('/ipam/vlan-groups/', **kwargs)
 
     def create_vlan_group(self, name, slug, **kwargs):
