@@ -1,4 +1,6 @@
 import netbox.exceptions as exceptions
+
+
 class Virtualization(object):
 
     def __init__(self, netbox_con):
@@ -8,37 +10,30 @@ class Virtualization(object):
         """Return all clusters"""
         return self.netbox_con.get('/virtualization/clusters/', **kwargs)
 
-    def get_cluster(self, **kwargs):
-        """Return the cluster by filter
-
-        :param kwargs: filter options
-        :return: cluster
-        """
-        return self.netbox_con.get('/virtualization/clusters/', **kwargs)
-
     def create_cluster(self, name, type, **kwargs):
         """Create a new cluster
 
         :param name: name of the cluster
         :param type: cluster type
         :param kwargs: optional arguments
-        :return: bool True if successful otherwise exception raised
+        :return: netbox object if successful otherwise exception raised
         """
         try:
-            type_id = self.get_cluster_type(type)[0]['id']
+            cluster_type_id = self.get_cluster_types(name=type)[0]['id']
         except IndexError:
-            raise exceptions.NotFoundException('type: {} or name: {}'.format(type, name)) from None
-        required_fields = {"name": name, "type": type_id}
+            raise exceptions.NotFoundException('cluster-type: {}'.format(name)) from None
+
+        required_fields = {"name": name, "type": cluster_type_id}
         return self.netbox_con.post('/virtualization/clusters/', required_fields, **kwargs)
 
     def delete_cluster(self, name):
         """Delete a cluster
 
         :param name: name of the cluster to delete
-        :return: bool True if succesful otherwase delete exception
+        :return: netbox object if succesful otherwase delete exception
         """
         try:
-            cluster_id = self.get_cluster(name=name)[0]['id']
+            cluster_id = self.get_clusters(name=name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('cluster {}'.format(name)) from None
         return self.netbox_con.delete('/virtualization/clusters/', cluster_id)
@@ -51,7 +46,7 @@ class Virtualization(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            cluster_id = self.get_cluster(name=name)[0]['id']
+            cluster_id = self.get_clusters(name=name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('cluster: {}'.format(name)) from None
         return self.netbox_con.patch('/virtualization/clusters/', cluster_id, **kwargs)
@@ -65,7 +60,7 @@ class Virtualization(object):
 
         :param name: name of the cluster
         :param slug: slug name
-        :return:  bool True if successful otherwise create exception
+        :return:  netbox object if successful otherwise create exception
         """
         required_fields = {"name": name, "slug": slug}
         return self.netbox_con.post('/virtualization/cluster-types/', required_fields)
@@ -78,7 +73,7 @@ class Virtualization(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            type_id = self.get_cluster_type(name)[0]['id']
+            type_id = self.get_cluster_types(name=name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException(name) from None
         return self.netbox_con.patch('/virtualization/cluster-types/', type_id, **kwargs)
@@ -90,7 +85,7 @@ class Virtualization(object):
         :return: bool True if succesful otherwase delete exception
         """
         try:
-            cluster_type_id = self.get_cluster_type(name=name)[0]['id']
+            cluster_type_id = self.get_cluster_types(name=name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('cluster-type: {}'.format(name)) from None
         return self.netbox_con.delete('/virtualization/cluster-types/', cluster_type_id)
@@ -108,7 +103,7 @@ class Virtualization(object):
 
         :param name: name of the interface
         :param virtual_machine: name of virtual machine to attach interface
-        :return: bool True if successful otherwise raise CreateException
+        :return: netbox object if successful otherwise raise CreateException
         """
         try:
             virtual_machine_id = self.get_virtual_machine(name=virtual_machine)[0]['id']
@@ -121,6 +116,7 @@ class Virtualization(object):
         """Update virtual_machine interface
 
         :param name: name of the interface to update
+        :param virtual_machine: name of the virtual-machine to update
         :param kwargs: update data
         :return: bool True if successful otherwise raise UpdateException
         """
@@ -153,3 +149,44 @@ class Virtualization(object):
     def get_virtual_machine(self, **kwargs):
         """Return virtual-machine based on filter"""
         return self.netbox_con.get('/virtualization/virtual-machines/', **kwargs)
+
+    def create_virtual_machine(self, name, cluster_name, **kwargs):
+        """Create a virtual machine
+    
+        :param name: name of the virtual machine
+        :param cluster_name: Name of existing cluster
+        :return: netbox object if successful otherwise raise CreateException
+        """
+        try:
+            cluster_id = self.get_clusters(name=cluster_name)[0]['id']
+        except IndexError:
+            raise exceptions.NotFoundException('cluster-name: {}'.format(cluster_name)) from None
+
+        required_fields = {"name": name, "cluster": cluster_id}
+        return self.netbox_con.post('/virtualization/virtual-machines/', required_fields, **kwargs)
+
+    def delete_virtual_machine(self, virtual_machine_name):
+        """Delete virtual machine
+
+        :param virtual_machine_name: name of the virtual machine to delete
+        :return: bool True if successful otherwise raise exception
+        """
+        try:
+            virtual_machine_id = self.get_virtual_machines(name=virtual_machine_name)[0]['id']
+        except IndexError:
+            raise exceptions.NotFoundException('virtual-machine: {}'.format(virtual_machine_name)) from None
+        return self.netbox_con.delete('/virtualization/virtual-machines/', virtual_machine_id)
+
+    def update_virtual_machine(self, virtual_machine_name, **kwargs):
+        """Update virtual-machine
+
+        :param virtual_machine_name: name of the virtual-machine to update
+        :param kwargs: update data
+        :return: bool True if successful otherwise raise UpdateException
+        """
+        try:
+            virtual_machine_id = self.get_virtual_machines(name=virtual_machine_name)[0]['id']
+        except IndexError:
+            raise exceptions.NotFoundException('virtual-machine: {}'
+                                               .format(virtual_machine_name)) from None
+        return self.netbox_con.patch('/virtualization/virtual-machines/', virtual_machine_id, **kwargs)
